Learn R Programming

ArchaeoPhases (version 1.8)

DatesHiatus: Test for the existence of a hiatus between two parameters

Description

Finds if a gap exists between two dates and returns the longest interval that satisfies: \(P(a_chain < IntervalInf < IntervalSup < b_chain | M) = level\)

Usage

DatesHiatus(a_chain, b_chain, level = 0.95)

Arguments

a_chain

: Numeric vector containing the output of the MCMC algorithm for the first parameter.

b_chain

: Numeric vector containing the output of the MCMC algorithm for the second parameter.

level

Probability corresponding to the confidence level of the interval.

Value

A named vector with the level and the endpoints of the gap in calendar years (AD/BC)

Examples

Run this code
# NOT RUN {
  data(Events); attach(Events)
  DatesHiatus(Event.1, Event.12)
  DatesHiatus(Event.1, Event.12, level = 0.5)

# }

Run the code above in your browser using DataLab