Learn R Programming

ArchaeoPhases (version 1.4.5)

Events: Events

Description

Contains the output of the MCMC algorithm for four events modelled by ChronoModel. The MCMC samples are in calendar year (BC/AD).

Usage

data(Events)

Arguments

Format

A data frame with 30000 observations on the following 5 variables.

iter

a numeric vector corresponding to iteration number

Event.1

a numeric vector containing the output of the MCMC algorithm for the parameter Event 1

Event.12

a numeric vector containing the output of the MCMC algorithm for the parameter Event 12

Event.2

a numeric vector containing the output of the MCMC algorithm for the parameter Event 2

Event.22

a numeric vector containing the output of the MCMC algorithm for the parameter Event 22

Examples

Run this code
# NOT RUN {
data(Events)
# }

Run the code above in your browser using DataLab