Learn R Programming

ArchaeoPhases (version 1.4)

KADatesChronoModel: Ksar Akil chronology build with ChronoModel software. Dates part.

Description

MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with ChronoModel software.

Usage

data("KADatesChronoModel")

Arguments

Format

A data frame with 30000 observations on the following 17 variables, one variable per AMS date and the MCMC iteration number. These observations come from 3 parallel chains. The MCMC samples are in calendar year (BC/AD).

iter

a numeric vector corresponding to iteration number

Layer.V

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer V.

Layer.VI

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer VI.

Layer.XI

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XI.

Layer.XII

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XII.

Layer.XVI.1

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.

Layer.XVI.2

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.

Layer.XVI.3

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.

Layer.XVI.4

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.

Layer.XVII.1

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.

Layer.XVII.2

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.

Layer.XVII.3

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.

Layer.XVII.4

a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.

Layer.XVIII

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XVIII.

Layer.XIX

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XIX.

Layer.XX

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XX.

Layer.XXII

a numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XXII.

References

Lanos, P. et al. (2016) Chronomodel : Chronological Modelling of Archaeological Data using Bayesian Statistics (Version 1.5). www.chronomodel.fr

Vibet. M.-A. et al. (2016) ChronoModel V1.5 User's manual.

Examples

Run this code
# NOT RUN {
##load data
data("KADatesChronoModel")
# }

Run the code above in your browser using DataLab