MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with Oxcal software. See Bosch, M. et al. (2015) for more details. The MCMC samples are in calendar year (BC/AD).
data(KADatesOxcal)A data frame with 10000 observations on the following 28 variables contained in the outputs generated by Oxcal.
Passa numeric vector corresponding to iteration number
Ethelrudaa numeric vector containing the output of the MCMC algorithm for .
start.dated.IUPa numeric vector containing the output of the MCMC algorithm for the date of the start of phase IUP.
GrA.53000a numeric vector containing the output of the MCMC algorithm for the date GrA.53000.
end.dated.IUPa numeric vector containing the output of the MCMC algorithm for the date of the end of phase IUP.
start.Ahmariana numeric vector containing the output of the MCMC algorithm for the date of the start of phase Ahmarian.
GrA.57597a numeric vector containing the output of the MCMC algorithm for the date GrA.57597.
GrA.53004a numeric vector containing the output of the MCMC algorithm for the date GrA.53004.
GrA.57542a numeric vector containing the output of the MCMC algorithm for the date GrA.57542.
GrA.54846a numeric vector containing the output of the MCMC algorithm for the date GrA.54846.
GrA.57603a numeric vector containing the output of the MCMC algorithm for the date GrA.57603.
GrA.57602a numeric vector containing the output of the MCMC algorithm for the date GrA.57602.
GrA.53001a numeric vector containing the output of the MCMC algorithm for the date GrA.53001.
Egberta numeric vector containing the output of the MCMC algorithm for the date Egbert.
GrA.54847a numeric vector containing the output of the MCMC algorithm for the date GrA.54847.
GrA.57599a numeric vector containing the output of the MCMC algorithm for the date GrA.57599.
GrA.57598a numeric vector containing the output of the MCMC algorithm for the date GrA.57598.
GrA.57544a numeric vector containing the output of the MCMC algorithm for the date GrA.57544.
end.Ahmariana numeric vector containing the output of the MCMC algorithm for the date of the end of phase Ahmarian.
start.UPa numeric vector containing the output of the MCMC algorithm for the date of the start of phase UP.
GrA.57545a numeric vector containing the output of the MCMC algorithm for the date GrA.57545.
GrA.53006a numeric vector containing the output of the MCMC algorithm for the date GrA.53006.
GrA.54848a numeric vector containing the output of the MCMC algorithm for the date GrA.54848.
end.UPa numeric vector containing the output of the MCMC algorithm for the date of the end of phase UP.
start.EPIa numeric vector containing the output of the MCMC algorithm for the date of the start of phase EPI.
GrA.53005a numeric vector containing the output of the MCMC algorithm for the date GrA.53005.
end.EPIa numeric vector containing the output of the MCMC algorithm for the date of the end of phase EPI.
Bronk Ramsey, C. (2009) Bayesian analysis of radiocarbon dates. Radiocarbon, 51(1), 337-360.
Bronk Ramsey, C. (2016) Oxcal 4.2.
# NOT RUN {
##load data
data(KADatesOxcal)
# }
Run the code above in your browser using DataLab