MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with ChronoModel software. The MCMC samples are in calendar year (BC/AD).
data("KAPhasesChronoModel")A data frame with 30000 observations on the following 9 variables, two variables for each group of dates and the MCMC iteration number. These four phases are in stratigraphic order, the order from the oldest to the youngest phase being : IUP, Ahmarian, UP and EPI.These observations come from 3 parallel chains.
itera numeric vector corresponding to iteration number
EPI.alphaa numeric vector containing the output of the MCMC algorithm for the minimum of the phase "EPI".
EPI.betaa numeric vector containing the output of the MCMC algorithm for the maximum of the phase "EPI".
UP.alphaa numeric vector containing the output of the MCMC algorithm for the the minimum of the phase "UP".
UP.betaa numeric vector containing the output of the MCMC algorithm for the maximum of the phase "UP".
Ahmarian.alphaa numeric vector containing the output of the MCMC algorithm for the the minimum of the phase "Ahmarian".
Ahmarian.betaa numeric vector containing the output of the MCMC algorithm for the maximum of the phase "Ahmarian".
IUP.alphaa numeric vector containing the output of the MCMC algorithm for the minimum of the phase "IUP".
IUP.betaa numeric vector containing the output of the MCMC algorithm for the maximum of the phase "IUP".
Lanos, P. et al. (2016) Chronomodel : Chronological Modelling of Archaeological Data using Bayesian Statistics (Version 1.5). www.chronomodel.fr
Vibet. M.-A. et al. (2016) ChronoModel V1.5 User's manual.
# NOT RUN {
##load data
data(KAPhasesChronoModel)
# }
Run the code above in your browser using DataLab