An S4 class to represent the output of a MCMC algorithm.
.DataA numeric matrix giving the MCMC samples expressed in
rata die.
labelsA character vector specifying the name of the events.
depthA numeric vector giving the sample depth.
hashA character string giving the 32-byte MD5 hash of the
original data file.
In the code snippets below, x is a MCMC object.
N. Frerebeau
Other classes:
ActivityEvents-class,
AgeDepthModel-class,
CumulativeEvents-class,
DurationsMCMC-class,
EventsMCMC-class,
OccurrenceEvents-class,
PhasesMCMC-class,
TimeRange-class