Learn R Programming

ArchaeoPhases (version 1.4)

MarginalStatistics: Marginal summary statistics

Description

Gives a list of summary statistics resulting from the output of the MCMC algorithm for a one-parameter. Results are given in calendar year (BC/AD).

Usage

MarginalStatistics(a_chain, level = 0.95)

Arguments

a_chain

numeric vector containing the output of the MCMC algorithm for a one-parameter. The MCMC samples should be in calendar year (BC/AD).

level

probability corresponding to the level of confidence used for the credible interval and the highest density region

Value

A matrix of values corresponding to the following summary statistics

title

The title of the summary statistics

mean

The mean of the MCMC chain. Use of "mean" function.

map

The maximum a posteriori of the MCMC chain. Use of "hdr" function.

sd

The standard deviation of the MCMC chain. Use of "sd" function.

Q1, median, Q3

The quantiles of the MCMC chain corresponding to 0.25, 0.50 and 0.75. Use of "quantile" function.

CI

The credible interval corresponding to the desired level. Use of "CredibleInterval" function.

HPDR

The highest posterior density regions corresponding to the desired level. Use of "hdr" function.

The results are given in calendar year (in format BC/AD).

Details

The 100*level % HPD (highest posterior density) region is estimated using HDR function from Package 'hdrcde'.

References

Hyndman, R.J. (1996) Computing and graphing highest density regions. American Statistician, 50, 120-126.

Examples

Run this code
# NOT RUN {
  data(Events); attach(Events)
  
  MarginalStatistics(Event.1)
  MarginalStatistics(Event.2, level = 0.90)
  
# }

Run the code above in your browser using DataLab