Learn R Programming

ArchaeoPhases (version 1.4.5)

MultiCredibleInterval: Bayesian credible intervals for a series of dates

Description

Estimation of the shorest credible interval for each variables of simulated Markov chain.

Usage

MultiCredibleInterval(data, position, level = 0.95)

Arguments

data

dataframe containing the output of the MCMC algorithm. The MCMC samples should be in calendar year (BC/AD).

position

numeric vector containing the position of the column corresponding to the MCMC chains of interest

level

probability corresponding to the level of confidence used to estimate the credible interval

Value

Returns a matrix of values containing the level of confidence and the endpoints of the shortest credible interval for each variable of the MCMC chain. The name of the resulting rows are the positions of the corresponding columns in the CSV file. The result is given in calendar year (in format BC/AD).

Examples

Run this code
# NOT RUN {
  data(Events)
  MultiCredibleInterval(Events, c(2,4,3), 0.95)
# }

Run the code above in your browser using DataLab