Learn R Programming

ArchaeoPhases (version 1.8)

MultiPhasesGap: Gap or hiatus between a succession of groups (for groups in temporal order constraint)

Description

Finds, if it exists, a gap or hiatus between two successive groups. This gap or hiatus is the longest interval that satisfies \(P(Phase1Max < IntervalInf < IntervalSup < Phase2Min | M) = level\)

Usage

MultiPhasesGap(
  data,
  position_minimum,
  position_maximum = position_minimum + 1,
  level = 0.95
)

Arguments

data

Data frame containing the output of the MCMC algorithm.

position_minimum

Numeric vector containing the column number corresponding to the minimum of the events included in each group.

position_maximum

Numeric vector containing the column number corresponding to the end of the phases set in the same order as in position_minimum.

level

Probability corresponding to the level of confidence.

Value

Returns a matrix of values containing the level of confidence and the endpoints of the gap for each pair of successive groups. The result is given in calendar years (BC/AD).

Details

For each i, MultiPhasesGap() computes the gap interval for the phase defined by its minimum position_minimum[i] and its maximum position_maximum[i]. The default value of position_maximum corresponds to CSV files exported from ChronoModel software.

Examples

Run this code
# NOT RUN {
  # Data extracted from ChronoModel software
  data(Phases)
  # List of the name of the groups
  names(Phases)
  # Stipulating position_maximum
  MultiPhasesGap(Phases, position_minimum = c(4, 2), position_maximum = c(5, 3))
  # In this case, equivalent to
  MultiPhasesGap(Phases, position_minimum = c(4, 2))

# }

Run the code above in your browser using DataLab