Learn R Programming

ArchaeoPhases (version 1.1)

MultiPhasesTransition: Transition range for a succession of groups (for groups in temporal order constraint)

Description

Finds if it exists the shortest interval [TransitionRangeInf, TransitionRangeSup] that satisfies : P(TransitionRangeInf < Phase1Max < Phase2Min < TransitionRangeSup | M) = level for each phase

Usage

MultiPhasesTransition(data, position_minimum, position_maximum = position_minimum+1, 
level = 0.95)

Arguments

data

dataframe containing the output of the MCMC algorithm. The MCMC samples should be in calendar year (BC/AD).

position_minimum

numeric vector containing the column number corresponding to the minimum of the dates included in each group

position_maximum

numeric vector containing the column number corresponding to the maximum of the dates included in each group. By default, position_maximum = position_minimum + 1.

level

probability corresponding to the level of confidence

Value

Returns a matrix of values containing the level of confidence and the endpoints of the transition interval for each pair of successive groups. The result is given in calendar year (in format BC/AD).

Details

For each i, MultiPhasesTransition computes the transition interval for the group defined by its minimum position_minimum[i] and its maximum position_maximum[i]. The default value of position_maximum corresponds to CSV files exported from ChronoModel software.

Examples

Run this code
  # Data extracted from ChronoModel software
  data(Phases)
  
  # List of the name of the groups 
  names(Phases)
  
  # Stipulating position_maximum
  MultiPhasesTransition(Phases, c(4,2), c(5,3))
  
  # In this case, equivalent to 
  MultiPhasesTransition(Phases, c(4,2))

Run the code above in your browser using DataLab