Learn R Programming

ArchaeoPhases (version 1.4.5)

PhaseStatistics: Summary statistics of a phase

Description

Estimation of several summary statistics of the minimum, the maximum and the duration of the dates included in the phase.

Usage

PhaseStatistics(PhaseMin_chain, PhaseMax_chain, level = 0.95)

Arguments

PhaseMin_chain

numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the phase. The MCMC samples should be in calendar year (BC/AD).

PhaseMax_chain

numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the phase. The MCMC samples should be in calendar year (BC/AD).

level

probability corresponding to the level of confidence used for the credible interval and the highest density region

Value

Returns a list of values corresponding to the summary statistics:

1

Statistics of the minimum of the dates included in the phase

2

Statistics of the maximum of the dates included in the phase

3

Statistics of the duration of the dates included in the phase

The results are given in calendar year (in format BC/AD).

Details

The summary statistics are those given by MarginalStatistics function. The time range is given by PhaseTimeRange function. The duration is computed as follow duration = maximum - minimum at each iteration of the MCMC output.

Examples

Run this code
# NOT RUN {
  data(Phases); attach(Phases)
  PhaseStatistics(Phase.1.alpha, Phase.1.beta, 0.95)
  PhaseStatistics(Phase.2.alpha, Phase.2.beta, 0.95)
# }

Run the code above in your browser using DataLab