numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the phase
PhaseMax_chain
numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the phase
level
probability corresponding to the desired level of confidence
Value
A vector of values containing the desired level of confidence and the endpoints of the shortest time range associated with this desired level. The result is given in calendar year (in format BC/AD).