PhasesGap: Gap or hiatus between two successive phases (for phases in temporal order constraint)
Description
This function finds, if it exists, a gap or hiatus between two successive phases.
This gap or hiatus is the longest interval that satisfies
\(P(Phase1Max_chain < IntervalInf < IntervalSup < Phase2Min_chain | M) = level\)
Numeric vector containing the output of the MCMC
algorithm for the maximum of the events included in the oldest phase.
Phase2Min_chain
Numeric vector containing the output of the MCMC
algorithm for the minimum of the events included in the following phase.
level
Probability corresponding to the level of confidence.
Value
Returns a vector of values containing the level of confidence and
the endpoints of the gap between the successive phases. The result is
given in calendar years (BC/AD).