Learn R Programming

ArchaeoPhases (version 2.1.0)

PhasesMCMC-class: MCMC Phases

Description

An S4 class to represent a collection of phases.

Arguments

Slots

labels

A character vector specifying the name of the phases.

hash

A character string giving the 32-byte MD5 hash of the original data file.

Subset

In the code snippets below, x is a PhasesMCMC object.

x[[i]]

Extracts a single phase (two chains) selected by subscript i. i is a length-one numeric or character vector.

Author

N. Frerebeau

Details

A phase object is an\(n x m x 2\) array, with \(n\) being the number of iterations, \(m\) being the number of phases and with the 2 columns of the third dimension containing the boundaries of the phases expressed in rata die.

See Also

Other classes: ActivityEvents-class, AgeDepthModel-class, CumulativeEvents-class, DurationsMCMC-class, EventsMCMC-class, MCMC-class, OccurrenceEvents-class, TimeRange-class