Learn R Programming

ArchaeoPhases (version 1.4)

SuccessionPlot: Density Plots of two successive groups (for groups in temporal order constraint)

Description

Plot of the densities of the minimum and the maximum of the dates included in each phase and adds several summary statistics (mean, CI, HPDR). The result is given in calendar year (in format BC/AD).

Usage

SuccessionPlot(Phase1Min_chain, Phase1Max_chain, Phase2Min_chain,
  Phase2Max_chain, level = 0.95,
  title = "Characterisation of a succession of groups", 
  exportFile = NULL, exportFormat = "PNG", GridLength = 1024)

Arguments

Phase1Min_chain

numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the oldest phase. The MCMC samples should be in calendar year (BC/AD).

Phase1Max_chain

numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the oldest phase. The MCMC samples should be in calendar year (BC/AD).

Phase2Min_chain

numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the youngest phase. The MCMC samples should be in calendar year (BC/AD).

Phase2Max_chain

numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the youngest phase. The MCMC samples should be in calendar year (BC/AD).

level

probability corresponding to the level of confidence

title

title of the graph

exportFile

the name of the file to be saved. If NULL then no graph is saved.

exportFormat

the format of the export file : SVG or PNG.

GridLength

length of the grid used to estimate the density

Value

Plot of the densities of the minimum and the maximum of the dates included in each phase. The result is given in calendar year (in format BC/AD).

Details

Curves represent the density of the minimum (oldest dates) and the maximum (youngest dates) of the dates included in each phase. Curves of the same color refer to the same phase. Time range intervals are symbolised by segments above the curves drawn using the same color as the one of the curves of the associated phase. Transition and gap range intervals are represented by two-coloured segments using the colors of the both phases in succession. If the gap between the successive phases does not exist, a cross is drawn instead of a segment.

Examples

Run this code
# NOT RUN {
  data(Phases); attach(Phases)
  SuccessionPlot(Phase.1.alpha, Phase.1.beta, Phase.2.alpha, Phase.2.beta, level = 0.95)
  SuccessionPlot(Phase.1.alpha, Phase.1.beta, Phase.2.alpha, Phase.2.beta, 
  exportFile = "Succession", exportFormat = "PNG")
# }

Run the code above in your browser using DataLab