A statistical graphic designed for the archaeological study of rhythms of the long term that embodies a theory of archaeological evidence for the occurrence of events.
TempoActivityPlot(data, position, plot.result = NULL, level = 0.95,
title = "Activity plot",
subtitle = NULL, caption = "ArcheoPhases",
x.label = "Calendar year",
y.label = "Activity",
line.types = c("solid"),
width = 7, height = 7, units = "in",
x.min = NULL, x.max = NULL,
file = NULL, x.scale = "calendar",
elapsed.origin.position = NULL,
newWindow=TRUE, print.data.result = FALSE)dataframe containing the output of the MCMC algorithm. The MCMC samples should be in calendar year (BC/AD).
numeric vector containing the position of the column corresponding to the MCMC chains of interest
a list containing the data to plot, typically the result of a previous run of TempoActivityPlot()
probability corresponding to the level of confidence used for the credible interval
title of the graph
subtitle of the graph
caption of the graph
x axis label of the graph
y axis label of the graph
type of the lines drawn of the graph in the order of legend.labels
height of the graph in units
width of the graph in units
recognized by ggsave function, one of "in", "cm", "mm"
minimum x axis value
maximum x axis value
one of "calendar" for calendar years, "BP" for years before present, or "elapsed" for years after a specified origin
the position of the column corresponding to the origin for elapsed time calculations
the name of the file to be saved. If NULL then no graph is saved.
whether the plot is drawn within a new window or not
If TRUE, the list containing the data to plot will be given
It is the derivative of the TempoPlot bayesian estimate. It may also return a list containing the data to plot (if print.data.result = TRUE). The result is given in calendar year (in format BC/AD).
Dye, T.S. (2016) Long-term rhythms in the development of Hawaiian social stratification. Journal of Archaeological Science, 71, 1--9.
# NOT RUN {
data(Events);
TempoActivityPlot(Events[1:1000,], c(2:5), print.data.result=FALSE)
TempoActivityPlot(Events[1:1000,], c(2:5), print.data.result=FALSE)
# }
Run the code above in your browser using DataLab