Learn R Programming

ArchaeoPhases (version 2.1.0)

allen_illustrate_relations: Data for an Illustrative Graphic

Description

Create a data frame that can be used as input for an illustrative plot. Useful for describing the Allen operators: illustrate the full set of Allen relations, concurrent Allen relations, and relations with distinct endpoints. Also, useful for describing the chronological domains of stratification, branching, transformation, and reticulation.

Usage

allen_illustrate_relations(relations = "basic")

Value

A data.frame to be passed to allen_plot().

Arguments

relations

A character string specifying the relation. It must be one of "basic", "concurrent", "distinct", "stratigraphic", "branching", "transformation", "reticulation", "sequence", "branch", "transform", or "reticulate" (see details).

Author

T. S. Dye

Details

The illustrative graphics include:

basic

the 13 basic Allen relations (default);

concurrent

concurrent relations;

distinct

relations with distinct endpoints;

stratigraphic

basic relations established by an observation of superposition;

branching

basic branching relations;

transformation

basic relations of transformation;

reticulation

basic relations of reticulation;

sequence

composite relations in a stratigraphic sequence;

branch

composite relations of branching;

transform

composite relations of transformation; or

reticulate

composite relations of reticulation.

See Also

Other Allen's intervals: allen_analyze(), allen_analyze_relations(), allen_complement(), allen_composition(), allen_converse(), allen_illustrate(), allen_intersect(), allen_joint_concurrency(), allen_observe(), allen_observe_frequency(), allen_plot(), allen_relation(), allen_relation_code(), allen_union()