Learn R Programming

ArchaeoPhases (version 2.1.0)

allen_joint_concurrency: Joint Concurrence of Two or More Observed Intervals

Description

Estimates the age of an undated context based on the known depositional history of associated artifacts.

Usage

allen_joint_concurrency(x, groups, ...)

# S4 method for EventsMCMC,list allen_joint_concurrency(x, groups, ...)

Value

A PhasesMCMC object.

Arguments

x

An EventsMCMC object containing the output of the MCMC algorithm.

groups

A list of (named) vector of names or indexes of columns in x (see phases()).

...

Currently not used.

Author

T. S. Dye

See Also

Other Allen's intervals: allen_analyze(), allen_analyze_relations(), allen_complement(), allen_composition(), allen_converse(), allen_illustrate(), allen_illustrate_relations(), allen_intersect(), allen_observe(), allen_observe_frequency(), allen_plot(), allen_relation(), allen_relation_code(), allen_union()