Learn R Programming

ArchaeoPhases (version 2.1.0)

allen_relate_intervals: Relate Two or More Observed Intervals

Description

Reads MCMC output to create a data frame suitable for plotting the observed Allen relation of two intervals.

Usage

allen_relate_intervals(mcmc, converse = TRUE)

Value

A list of data.frame to be passed to allen_plot().

Arguments

mcmc

An EventsMCMC object containing the output of the MCMC algorithm.

converse

A logical scalar: should converse relations be observed?

Author

T. S. Dye, N. Frerebeau