Learn R Programming

ArchaeoPhases (version 1.4.5)

app_ArchaeoPhases: Run ArchaeoPhases shiny apps

Description

A wrapper for runApp to start interactive shiny apps for the R package ArchaeoPhases.

Usage

app_ArchaeoPhases()

Arguments

Details

The ArchaeoPhases package provides a function from which a shiny app can be started: app_ArchaeoPhases(). The app_ArchaeoPhases() function is just a wrapper for runApp. Via the ... argument further arguments can be directly passed to runApp. See ?shiny::runApp for further details on valid arguments.

See Also

runApp

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
app_ArchaeoPhases()

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab