Computes the age-depth curve from the output of the MCMC algorithm and the known depth of each dated samples.
bury(object, depth, ...)# S4 method for EventsMCMC,numeric
bury(object, depth, span = 0.75, degree = 2)
# S4 method for AgeDepthModel
predict(object, newdata)
# S4 method for AgeDepthModel,missing
plot(
x,
level = 0.95,
calendar = get_calendar(),
main = NULL,
sub = NULL,
ann = graphics::par("ann"),
axes = TRUE,
frame.plot = axes,
panel.first = NULL,
panel.last = NULL,
...
)
An EventsMCMC object.
A numeric vector giving of the depths of the dated samples.
Other graphical parameters may also be passed as
arguments to this function, particularly, border, col, lwd, lty or
pch.
A length-one numeric vector giving the regression parameter
(see stats::loess()).
A length-one numeric vector giving the degree of the
polynomials to be used (see stats::loess()).
A numeric vector giving the depths at which ages will be
predicted. If missing, the original data points are used.
An AgeDepthModel object.
A length-one numeric vector giving the confidence level.
A aion::TimeScale object specifying the target
calendar (see aion::calendar()).
A character string giving a main title for the plot.
A character string giving a subtitle for the plot.
A logical scalar: should the default annotation (title and x
and y axis labels) appear on the plot?
A logical scalar: should axes be drawn on the plot?
A logical scalar: should a box be drawn around the
plot?
An an expression to be evaluated after the plot axes are
set up but before any plotting takes place. This can be useful for drawing
background grids.
An expression to be evaluated after plotting has taken
place but before the axes, title and box are added.
A. Philippe
We assume it exists a function \(f\) relating the age and the depth \(age = f(depth)\). We estimate the function using local regression (also called local polynomial regression): \(f = loess(age ~ depth)\). This estimated function \(f\) depends on the unknown dates. However, from the posterior distribution of the age/date sequence, we can evaluate the posterior distribution of the age function for each desired depth.
Jha, D. K., Sanyal, P. & Philippe, A. (2020). Multi-Proxy Evidence of Late Quaternary Climate and Vegetational History of North-Central India: Implication for the Paleolithic to Neolithic Phases. Quaternary Science Reviews, 229: 106121. tools:::Rd_expr_doi("10.1016/j.quascirev.2019.106121").
Ghosh, S., Sanyal, P., Roy, S., Bhushan, R., Sati, S. P., Philippe, A. & Juyal, N. (2020). Early Holocene Indian Summer Monsoon and Its Impact on Vegetation in the Central Himalaya: Insight from dD and d13C Values of Leaf Wax Lipid. The Holocene, 30(7): 1063-1074. tools:::Rd_expr_doi("10.1177/0959683620908639").
Other age-depth modeling tools:
interpolate()
## Coerce to MCMC
eve <- matrix(rnorm(6000, (1:6)^2), ncol = 6, byrow = TRUE)
eve <- as_events(eve, calendar = CE())
## Compute an age-depth curve
age <- bury(eve, depth = 1:6)
plot(age)
## Predict new values
new <- predict(age, newdata = 1.5:5.5)
summary(new)
plot(eve)
plot(new)
Run the code above in your browser using DataLab