Learn R Programming

ArchaeoPhases (version 2.1.0)

elapse: Elapsed Time Scale

Description

Elapsed Time Scale

Usage

elapse(object, ...)

# S4 method for MCMC elapse(object, origin = 1)

Value

Returns an object of the same class as object with an elapsed

An object of the same sort as object with a new time scale.

Arguments

object

An object (typically an MCMC object).

...

Currently not used.

origin

An integer giving the position of the column corresponding to the event from which elapsed time is calculated.

Author

N. Frerebeau

See Also

Other event tools: activity(), occurrence(), tempo()

Examples

Run this code
## Coerce to events
eve <- as_events(mcmc_events, calendar = CE(), iteration = 1)

## Elapsed origin
eve_elapse <- elapse(eve, origin = 4)
plot(eve_elapse)

Run the code above in your browser using DataLab