Learn R Programming

ArchaeoPhases (version 2.1.0)

names: The Names of an Object

Description

Get or set the names of an object.

Usage

# S4 method for MCMC
names(x)

# S4 method for MCMC names(x) <- value

# S4 method for PhasesMCMC names(x)

# S4 method for PhasesMCMC names(x) <- value

Value

An object of the same sort as x with the new names assigned.

Arguments

x

An object from which to get or set names.

value

A possible value for the names of x.

Author

N. Frerebeau

See Also

Other mutators: bind, data.frame, sort(), sort.list(), subset()