Learn R Programming

ArchaeoPhases (version 1.8)

original_file.archaeophases_mcmc: Check for an original mcmc file

Description

Checks whether or not a file is identical to the one used to create an archaeophases_mcmc object.

Usage

# S3 method for archaeophases_mcmc
original_file(x, file = NULL, ...)

Arguments

x

An archaeophases_mcmc object.

file

Either a path to a CSV file, a connection, or the value clipboard() to read from the system clipboard. The CSV file can be compressed or plain.

...

Other parameters.

Value

A boolean, TRUE if the files match, FALSE otherwise.

Details

If called with a single argument, checks the file indicated by the file_path attribute.