archaeophases_plot fileChecks whether or not a file is identical to the one used to create
an archaeophases_plot object.
# S3 method for archaeophases_plot
original_file(x, file = NULL, ...)An archaeophases_plot object.
Either a path to a plot file, a connection,
or the value clipboard() to read from the system clipboard.
Other parameters.
A boolean, TRUE if the files match, FALSE
otherwise.
If called with a single argument, checks the file indicated by
the file_path attribute.