Skip to contents

Reads MCMC output.

Usage

read_oxcal(file, ...)

# S4 method for class 'character'
read_oxcal(file, calendar = CE())

Arguments

file

A character string giving the name of the CSV file which the data are to be read from.

...

Currently not used.

calendar

A aion::TimeScale object specifying the calendar (see calendar()). It should be CE() unless you change the default settings in 'OxCal'.

Value

An EventsMCMC object.

References

Bronk Ramsey, C. (2009). Bayesian Analysis of Radiocarbon Dates. Radiocarbon, 51(1), 337-360. doi:10.1017/S0033822200033865 .

Author

T. S. Dye, N. Frerebeau

Examples

if (requireNamespace("ArchaeoData", quietly = TRUE)) {
  ## Construct the path to the data
  path <- file.path("oxcal", "ksarakil")
  path_output <- system.file(path, "MCMC_Sample.csv", package = "ArchaeoData")

  ## Import OxCal Output
  (oxcal <- read_oxcal(path_output))
}
#> <EventsMCMC>
#> - Number of events: 26
#> - Number of MCMC samples: 1000