A statistical graphic designed for the archaeological study of rhythms of the long term that embodies a theory of archaeological evidence for the occurrence of events.
tempo(object, ...)# S4 method for CumulativeEvents,missing
plot(
x,
calendar = get_calendar(),
interval = c("credible", "gauss"),
col.tempo = "#004488",
col.interval = "grey",
main = NULL,
sub = NULL,
ann = graphics::par("ann"),
axes = TRUE,
frame.plot = axes,
panel.first = NULL,
panel.last = NULL,
...
)
# S4 method for EventsMCMC
tempo(
object,
level = 0.95,
count = FALSE,
credible = TRUE,
gauss = TRUE,
from = min(object),
to = max(object),
grid = getOption("ArchaeoPhases.grid")
)
tempo() returns an CumulativeEvents object.
plot() is called it for its side-effects: it results in a graphic being
displayed (invisibly returns x).
An EventsMCMC object.
Other graphical parameters may also be passed as arguments to this function.
A CumulativeEvents object or an EventsMCMC
object.
A aion::TimeScale object specifying the target
calendar (see aion::calendar()).
A character string specifying the confidence interval to
be drawn. It must be one of "credible" (credible interval) or "gauss"
(Gaussian approximation of the credible interval). Any unambiguous substring
can be given.
A specification for the plotting colors.
A character string giving a main title for the plot.
A character string giving a subtitle for the plot.
A logical scalar: should the default annotation (title and x
and y axis labels) appear on the plot?
A logical scalar: should axes be drawn on the plot?
A logical scalar: should a box be drawn around the
plot?
An an expression to be evaluated after the plot axes are
set up but before any plotting takes place. This can be useful for drawing
background grids.
An expression to be evaluated after plotting has taken
place but before the axes, title and box are added.
A length-one numeric vector giving the confidence level.
A logical scalar: should the counting process be a number
or a probability (the default)?
A logical scalar: should the credible interval be
computed/displayed?
A logical scalar: should the Gaussian approximation of the
credible interval be computed/displayed?
A length-one numeric vector giving the earliest date to
estimate for (expressed in rata die).
A length-one numeric vector giving the latest date to estimate
for (expressed in rata die).
A length-one numeric vector specifying the number of equally
spaced points of the temporal grid.
A. Philippe, M.-A. Vibet, T. S. Dye, N. Frerebeau
The tempo plot is one way to measure change over time: it estimates the cumulative occurrence of archaeological events in a Bayesian calibration. The tempo plot yields a graphic where the slope of the plot directly reflects the pace of change: a period of rapid change yields a steep slope and a period of slow change yields a gentle slope. When there is no change, the plot is horizontal. When change is instantaneous, the plot is vertical.
Dye, T. S. (2016). Long-term rhythms in the development of Hawaiian social stratification. Journal of Archaeological Science, 71: 1-9. tools:::Rd_expr_doi("10.1016/j.jas.2016.05.006").
Other event tools:
activity(),
elapse(),
occurrence()
## Coerce to MCMC
eve <- as_events(mcmc_events, calendar = CE(), iteration = 1)
eve <- eve[1:10000, ]
## Tempo plot
tmp <- tempo(eve)
plot(tmp, interval = "credible", panel.first = grid())
plot(tmp, interval = "gauss", panel.first = grid())
## Activity plot
act <- activity(tmp)
plot(act, panel.first = grid())
Run the code above in your browser using DataLab