Statistical analysis of archaeological dates and groups of dates. This package allows to post-process Markov Chain Monte Carlo (MCMC) simulations from 'ChronoModel' https://chronomodel.com/, 'Oxcal' https://c14.arch.ox.ac.uk/oxcal.html or 'BCal' https://bcal.shef.ac.uk/. It provides functions for the study of rhythms of the long term from the posterior distribution of a series of dates (tempo and activity plot). It also allows the estimation and visualization of time ranges from the posterior distribution of groups of dates (e.g. duration, transition and hiatus between successive phases) as described in Philippe and Vibet (2020) tools:::Rd_expr_doi("10.18637/jss.v093.c01").
ArchaeoPhases uses the following options() to configure behaviour:
ArchaeoPhases.grid: a numeric value specifying the number of equally
spaced points at which densities are to be estimated (defaults to
\(512\)). Should be a power of \(2\).
ArchaeoPhases.precision: an integer indicating the number of decimal
places (defaults to \(0\)).
ArchaeoPhases.progress: a logical scalar specifying if progress bars
should be displayed (defaults to interactive()).
Maintainer: Anne Philippe anne.philippe@univ-nantes.fr (ORCID)
Authors:
Marie-Anne Vibet (ORCID)
Nicolas Frerebeau nicolas.frerebeau@u-bordeaux-montaigne.fr (ORCID)
Other contributors:
| Version | 2.0.1 |
| License | GPL-3 |
| CRAN DOI | tools:::Rd_expr_doi("10.32614/CRAN.package.ArchaeoPhases") |
| Zenodo DOI | tools:::Rd_expr_doi("10.5281/zenodo.8087121") |
| JSS DOI | tools:::Rd_expr_doi("10.18637/jss.v093.c01") |
Laboratoire de Mathématiques Jean Leray (UMR 6629)
2, rue de la Houssinière
BP 92208
F-44322 Nantes Cedex 3
France