Learn R Programming

ArchaeoPhases (version 1.1)

DatesHiatus: Test for the existence of a hiatus between two parameters

Description

Finds if it exists a gap between two dates that is the longest interval that satisfies : P(a_chain < IntervalInf < IntervalSup < b_chain | M) = level

Usage

DatesHiatus(a_chain, b_chain, level=0.95)

Arguments

a_chain

numeric vector containing the output of the MCMC algorithm for the first one-parameter (date) a.The MCMC samples should be in calendar year (BC/AD)

b_chain

numeric vector containing the output of the same MCMC algorithm for the second one-parameter (date) b. The MCMC samples should be in calendar year (BC/AD)

level

probability corresponding to the level of confidence used for the credible interval and the highest density region

Value

Returns the endpoints of the longest hiatus between two parameters. The result is given in calendar year (in format BC/AD).

Examples

Run this code
  data(Events); attach(Events)
  DatesHiatus(Event.1, Event.12)
  DatesHiatus(Event.1, Event.12, level = 0.5)

Run the code above in your browser using DataLab