MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with ChronoModel software.
data("KADatesChronoModel")A data frame with 30000 observations on the following 17 variables, one variable per AMS date and the MCMC iteration number. These observations come from 3 parallel chains. The MCMC samples are in calendar year (BC/AD).
itera numeric vector corresponding to iteration number
Layer.Va numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer V.
Layer.VIa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer VI.
Layer.XIa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XI.
Layer.XIIa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XII.
Layer.XVI.1a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.
Layer.XVI.2a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.
Layer.XVI.3a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.
Layer.XVI.4a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVI.
Layer.XVII.1a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.
Layer.XVII.2a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.
Layer.XVII.3a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.
Layer.XVII.4a numeric vector containing the output of the MCMC algorithm for the date of a shell extracted from layer XVII.
Layer.XVIIIa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XVIII.
Layer.XIXa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XIX.
Layer.XXa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XX.
Layer.XXIIa numeric vector containing the output of the MCMC algorithm for the date of the shell extracted from layer XXII.
Lanos, P. et al. (2016) Chronomodel : Chronological Modelling of Archaeological Data using Bayesian Statistics (Version 1.5). www.chronomodel.fr
Vibet. M.-A. et al. (2016) ChronoModel V1.5 User's manual.
# NOT RUN {
##load data
data("KADatesChronoModel")
# }
Run the code above in your browser using DataLab