Learn R Programming

ArchaeoPhases (version 1.1)

KADatesOxcal: Ksar Akil chronology build with Oxcal software

Description

MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with Oxcal software. See Bosch, M. et al. (2015) for more details. The MCMC samples are in calendar year (BC/AD).

Usage

data(KADatesOxcal)

Arguments

Format

A data frame with 10000 observations on the following 28 variables contained in the outputs generated by Oxcal.

Pass

a numeric vector corresponding to iteration number

Ethelruda

a numeric vector containing the output of the MCMC algorithm for .

start.dated.IUP

a numeric vector containing the output of the MCMC algorithm for the date of the start of phase IUP.

GrA.53000

a numeric vector containing the output of the MCMC algorithm for the date GrA.53000.

end.dated.IUP

a numeric vector containing the output of the MCMC algorithm for the date of the end of phase IUP.

start.Ahmarian

a numeric vector containing the output of the MCMC algorithm for the date of the start of phase Ahmarian.

GrA.57597

a numeric vector containing the output of the MCMC algorithm for the date GrA.57597.

GrA.53004

a numeric vector containing the output of the MCMC algorithm for the date GrA.53004.

GrA.57542

a numeric vector containing the output of the MCMC algorithm for the date GrA.57542.

GrA.54846

a numeric vector containing the output of the MCMC algorithm for the date GrA.54846.

GrA.57603

a numeric vector containing the output of the MCMC algorithm for the date GrA.57603.

GrA.57602

a numeric vector containing the output of the MCMC algorithm for the date GrA.57602.

GrA.53001

a numeric vector containing the output of the MCMC algorithm for the date GrA.53001.

Egbert

a numeric vector containing the output of the MCMC algorithm for the date Egbert.

GrA.54847

a numeric vector containing the output of the MCMC algorithm for the date GrA.54847.

GrA.57599

a numeric vector containing the output of the MCMC algorithm for the date GrA.57599.

GrA.57598

a numeric vector containing the output of the MCMC algorithm for the date GrA.57598.

GrA.57544

a numeric vector containing the output of the MCMC algorithm for the date GrA.57544.

end.Ahmarian

a numeric vector containing the output of the MCMC algorithm for the date of the end of phase Ahmarian.

start.UP

a numeric vector containing the output of the MCMC algorithm for the date of the start of phase UP.

GrA.57545

a numeric vector containing the output of the MCMC algorithm for the date GrA.57545.

GrA.53006

a numeric vector containing the output of the MCMC algorithm for the date GrA.53006.

GrA.54848

a numeric vector containing the output of the MCMC algorithm for the date GrA.54848.

end.UP

a numeric vector containing the output of the MCMC algorithm for the date of the end of phase UP.

start.EPI

a numeric vector containing the output of the MCMC algorithm for the date of the start of phase EPI.

GrA.53005

a numeric vector containing the output of the MCMC algorithm for the date GrA.53005.

end.EPI

a numeric vector containing the output of the MCMC algorithm for the date of the end of phase EPI.

References

Bronk Ramsey, C. (2009) Bayesian analysis of radiocarbon dates. Radiocarbon, 51(1), 337-360.

Bronk Ramsey, C. (2016) Oxcal 4.2.

Examples

Run this code
  ##load data
  data(KADatesOxcal)

Run the code above in your browser using DataLab