Learn R Programming

ArchaeoPhases (version 1.1)

KAPhasesChronoModel: Ksar Akil chronology build with ChronoModel software. Phases part.

Description

MCMC samples from the posterior distribution of dates included in the Ksar Akil chronology build with ChronoModel software. The MCMC samples are in calendar year (BC/AD).

Usage

data("KAPhasesChronoModel")

Arguments

Format

A data frame with 30000 observations on the following 9 variables, two variables for each group of dates and the MCMC iteration number. These four phases are in stratigraphic order, the order from the oldest to the youngest phase being : IUP, Ahmarian, UP and EPI.These observations come from 3 parallel chains.

iter

a numeric vector corresponding to iteration number

EPI.alpha

a numeric vector containing the output of the MCMC algorithm for the minimum of the phase "EPI".

EPI.beta

a numeric vector containing the output of the MCMC algorithm for the maximum of the phase "EPI".

UP.alpha

a numeric vector containing the output of the MCMC algorithm for the the minimum of the phase "UP".

UP.beta

a numeric vector containing the output of the MCMC algorithm for the maximum of the phase "UP".

Ahmarian.alpha

a numeric vector containing the output of the MCMC algorithm for the the minimum of the phase "Ahmarian".

Ahmarian.beta

a numeric vector containing the output of the MCMC algorithm for the maximum of the phase "Ahmarian".

IUP.alpha

a numeric vector containing the output of the MCMC algorithm for the minimum of the phase "IUP".

IUP.beta

a numeric vector containing the output of the MCMC algorithm for the maximum of the phase "IUP".

References

Lanos, P. et al. (2016) Chronomodel : Chronological Modelling of Archaeological Data using Bayesian Statistics (Version 1.5). www.chronomodel.fr

Vibet. M.-A. et al. (2016) ChronoModel V1.5 User's manual.

Examples

Run this code
##load data
data(KAPhasesChronoModel)

Run the code above in your browser using DataLab