dataframe containing the output of the MCMC algorithm. The MCMC samples should be in calendar year (BC/AD).
position
numeric vector containing the position of the column corresponding to the MCMC chains of interest
level
probability corresponding to the level of confidence used to estimate the credible interval
Value
Returns a matrix of values containing the level of confidence and the endpoints of the shortest credible interval for each variable of the MCMC chain. The name of the resulting rows are the positions of the corresponding columns in the CSV file. The result is given in calendar year (in format BC/AD).