Learn R Programming

ArchaeoPhases (version 1.1)

PhaseTimeRange: Phase Time Range

Description

Computes the shortest interval [IntervalInf ; IntervalSup ] that satisfies : P(PhaseMin_chain =< IntervalInf < IntervalSup =< PhaseMax_chain | M) = level.

Usage

PhaseTimeRange(PhaseMin_chain, PhaseMax_chain, level = 0.95)

Arguments

PhaseMin_chain

numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the phase

PhaseMax_chain

numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the phase

level

probability corresponding to the desired level of confidence

Value

A vector of values containing the desired level of confidence and the endpoints of the shortest time range associated with this desired level. The result is given in calendar year (in format BC/AD).

Examples

Run this code

  data(Phases); attach(Phases)
  PhaseTimeRange(Phase.1.alpha, Phase.1.beta, 0.95)
  PhaseTimeRange(Phase.2.alpha, Phase.2.beta, 0.90)

Run the code above in your browser using DataLab