Learn R Programming

ArchaeoPhases (version 1.1)

Phases: Phases

Description

Contains the output of the MCMC algorithm for all the phases (beginning and end) of two successive phases modelled in ChronoModel. Phase 1 is assued to be older than Phase 2. The MCMC samples are in calendar year (BC/AD).

Usage

data(Phases)

Arguments

Format

A data frame with 30000 observations on the following 5 variables.

iter

a numeric vector corresponding to iteration number

Phase.1.alpha

a numeric vector containing the output of the MCMC algorithm for the beginning of the phase "Phase 1"

Phase.1.beta

a numeric vector containing the output of the MCMC algorithm for the end of the phase "Phase 1"

Phase.2.alpha

a numeric vector containing the output of the MCMC algorithm for the the beginning of the phase "Phase 2"

Phase.2.beta

a numeric vector containing the output of the MCMC algorithm for the end of the phase "Phase 2"

Examples

Run this code
  data(Phases)
  attach(Phases)
  PhasePlot(Phase.1.alpha, Phase.1.beta)
  PhaseTimeRange(Phase.1.alpha, Phase.1.beta)

  PhasesGap(Phase.1.beta, Phase.2.alpha)
  PhasesTransition(Phase.1.beta, Phase.2.alpha)

Run the code above in your browser using DataLab