PhasesGap: Gap or Hiatus between two successive phases (for phases in temporal order constraint)
Description
This function finds, if it exists, the gap between two successive phases. This gap or hiatus is the longest interval [IntervalInf ; IntervalSup] that satisfies : P(Phase1Max_chain < IntervalInf < IntervalSup < Phase2Min_chain | M) = level.
numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the oldest phase. The MCMC samples should be in calendar year (BC/AD).
Phase2Min_chain
numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the youngest phase. The MCMC samples should be in calendar year (BC/AD).
level
probability corresponding to the level of confidence
Value
Returns a vector of values containing the level of confidence and the endpoints of the gap between the successive phases. The result is given in calendar year (in format BC/AD).
References
Anne Philippe, Marie-Anne Vibet. (2020). Analysis of Archaeological Phases using the CRAN Package 'ArchaeoPhases', <doi:10.18637/jss.v093.c01>.