Learn R Programming

ArchaeoPhases (version 1.4)

PhasesGap: Gap or Hiatus between two successive phases (for phases in temporal order constraint)

Description

This function finds, if it exists, the gap between two successive phases. This gap or hiatus is the longest interval [IntervalInf ; IntervalSup] that satisfies : P(Phase1Max_chain < IntervalInf < IntervalSup < Phase2Min_chain | M) = level.

Usage

PhasesGap(Phase1Max_chain, Phase2Min_chain, level = 0.95)

Arguments

Phase1Max_chain

numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the oldest phase. The MCMC samples should be in calendar year (BC/AD).

Phase2Min_chain

numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the youngest phase. The MCMC samples should be in calendar year (BC/AD).

level

probability corresponding to the level of confidence

Value

Returns a vector of values containing the level of confidence and the endpoints of the gap between the successive phases. The result is given in calendar year (in format BC/AD).

Examples

Run this code
# NOT RUN {
  data(Phases); attach(Phases)
  PhasesGap(Phase.1.beta, Phase.2.alpha, 0.95)
  PhasesGap(Phase.1.beta, Phase.2.alpha, 0.50)
# }

Run the code above in your browser using DataLab