An S4 class to represent a collection of phases.
labelsA character vector specifying the name of the phases.
hashA character string giving the 32-byte MD5 hash of the
original data file.
In the code snippets below, x is a PhasesMCMC object.
N. Frerebeau
A phase object is an\(n x m x 2\) array, with \(n\) being the number of iterations, \(m\) being the number of phases and with the 2 columns of the third dimension containing the boundaries of the phases expressed in rata die.
Other classes:
ActivityEvents-class,
AgeDepthModel-class,
CumulativeEvents-class,
DurationsMCMC-class,
EventsMCMC-class,
MCMC-class,
OccurrenceEvents-class,
TimeRange-class