PhasesTransition: Transition range between two successive phases (for phases in temporal order constraint)
Description
Finds if it exists the shortest interval [TransitionRangeInf , TransitionRangeSup ] that satisfies : P(TransitionRangeInf < Phase1Max_chain < Phase2Min_chain < TransitionRangeSup | M) = level
numeric vector containing the output of the MCMC algorithm for the maximum of the dates included in the oldest phase
Phase2Min_chain
numeric vector containing the output of the MCMC algorithm for the minimum of the dates included in the youngest phase
level
probability corresponding to the level of confidence
Value
Returns a vector of values containing the level of confidence and the endpoints of the transition interval between the successive phases. The result is given in calendar year (in format BC/AD).