A statistical graphic designed for the archaeological study of rhythms of the long term that embodies a theory of archaeological evidence for the occurrence of events.
TempoPlot(data, position, plot.result = NULL, level = 0.95,
count = TRUE, Gauss = FALSE, title = "Tempo plot",
subtitle = NULL, caption = "ArcheoPhases",
legend.title = "Legend",
legend.labels = c("Bayes estimate",
"Credible interval, low",
"Credible interval, high",
"Gaussian approx., high",
"Gaussian approx., low"),
x.label = "Calendar year",
y.label = "Cumulative events",
line.types = c("solid", "12", "11", "28", "28"),
width = 7, height = 7, units = "in",
x.min = NULL, x.max = NULL, colors = TRUE,
file = NULL, x.scale = "calendar",
elapsed.origin.position = NULL,
newWindow=TRUE, print.data.result = FALSE)dataframe containing the output of the MCMC algorithm. The MCMC samples should be in calendar year (BC/AD).
numeric vector containing the position of the column corresponding to the MCMC chains of interest
a list containing the data to plot, typically the result of a previous run of TempoPlot()
probability corresponding to the level of confidence used for the credible interval
if TRUE the counting process is given as a number, otherwise it is a probability
if TRUE, the Gaussian approximation of the CI is used
title of the graph
subtitle of the graph
caption of the graph
the title of the legend
a vector of strings to label legend entries
label of the x-axis
label of the y-axis
type of the lines drawn of the graph in the order of legend.labels
width of the plot in units
height of the plot in units
units used to specify width and height. One of "in", "cm", or "mm". Default = "in".
minimum value for x axis
maximum value for x axis
if TRUE, the graph is drawn with colors, otherwise it is drawn in black and white
the name of the graph (+ extension) that will be saved if chosen. Null by default.
one of "calendar", "bp", or "elapsed"
if x.scale is "elapsed", the position of the column corresponding to the occurrence from which elapsed time is calculated
whether the plot is drawn within a new window or not
If TRUE, the list containing the data to plot will be given. Default = TRUE.
It calculates the cumulative frequency of specified events by calculating how many events took place before each date in a specified range of dates. The result is given in calendar year (in format BC/AD). It may also return a list containing the data to plot (if print.data.result = TRUE).
The tempo plot is one way to measure change over time: it estimates the cumulative occurrence of archaeological events in a Bayesian calibration. The tempo plot yields a graphic where the slope of the plot directly reflects the pace of change: a period of rapid change yields a steep slope and a period of slow change yields a gentle slope. When there is no change, the plot is horizontal. When change is instantaneous, the plot is vertical.
Dye, T.S. (2016) Long-term rhythms in the development of Hawaiian social stratification. Journal of Archaeological Science, 71, 1--9.
# NOT RUN {
data(Events);
TempoPlot(Events[1:1000,], c(2:5), print.data.result = FALSE)
TempoPlot(Events[1:1000,], c(2:5), count = TRUE, print.data.result = FALSE)
# }
Run the code above in your browser using DataLab