Create a data frame that can be used as input for an illustrative plot. Useful for describing the Allen operators: illustrate the full set of Allen relations, concurrent Allen relations, and relations with distinct endpoints. Also, useful for describing the chronological domains of stratification, branching, transformation, and reticulation.
allen_illustrate_relations(relations = "basic")A data.frame to be passed to allen_plot().
A character string specifying the relation.
It must be one of "basic", "concurrent", "distinct",
"stratigraphic", "branching", "transformation", "reticulation",
"sequence", "branch", "transform", or "reticulate" (see details).
T. S. Dye
The illustrative graphics include:
basicthe 13 basic Allen relations (default);
concurrentconcurrent relations;
distinctrelations with distinct endpoints;
stratigraphicbasic relations established by an observation of superposition;
branchingbasic branching relations;
transformationbasic relations of transformation;
reticulationbasic relations of reticulation;
sequencecomposite relations in a stratigraphic sequence;
branchcomposite relations of branching;
transformcomposite relations of transformation; or
reticulatecomposite relations of reticulation.
Other Allen's intervals:
allen_analyze(),
allen_analyze_relations(),
allen_complement(),
allen_composition(),
allen_converse(),
allen_illustrate(),
allen_intersect(),
allen_joint_concurrency(),
allen_observe(),
allen_observe_frequency(),
allen_plot(),
allen_relation(),
allen_relation_code(),
allen_union()