allen_proportion_result: Calculate the proportion of each relation in a result vector
Description
Divides through by the sum of observations in the result vector.
Assigns the names of the result vector to the optionally sorted
return vector.
Usage
allen_proportion_result(result_vector, sort = FALSE)
Arguments
sort
if TRUE sort in decreasing order else return unsorted vector
Value
A named vector with proportions