Learn R Programming

ArchaeoPhases (version 1.8)

allen_relate_intervals: Relate two or more observed intervals

Description

Reads MCMC output to create a dataframe suitable for plotting the observed Allen relation of two intervals.

Usage

allen_relate_intervals(mcmc, chains)

Arguments

mcmc

Dataframe or archaeophases_mcmc object with the MCMC output from a Bayesian calibration.

chains

a list of lists, each with two named elements, each element a vector of names or indexes of columns in mcmc.

Value

A dataframe suitable for plotting with allen_plot.