Reads MCMC output to create a dataframe suitable for plotting the observed Allen relation of two intervals.
allen_relate_intervals(mcmc, chains)Dataframe or archaeophases_mcmc object with the MCMC output from a Bayesian calibration.
a list of lists, each with two named elements,
each element a vector of names or indexes of columns in mcmc.
A dataframe suitable for plotting with allen_plot.