Calculates the Allen relation of two definite intervals and reports the one-letter code for the interval proposed by Thomas Alspaugh. Stops with an error if the end of an interval is earlier than its start.
allen_relation(start_1, end_1, start_2, end_2)The start date of the first interval
The end date of the first interval
The start date of the second interval
The end date of the second interval
A one-letter code indicating the Allen relation