Learn R Programming

ArchaeoPhases (version 2.1.0)

hiatus: Hiatus Between Two Dates

Description

Tests for the existence of a hiatus between two parameters.

Usage

hiatus(x, y, ...)

# S4 method for numeric,numeric hiatus(x, y, level = 0.95)

# S4 method for EventsMCMC,missing hiatus(x, level = 0.95)

# S4 method for PhasesMCMC,missing hiatus(x, level = 0.95)

Value

The endpoints of the hiatus between successive events/phases (at a given level).

Arguments

x, y

A numeric vector. If y is missing, x must be an PhasesMCMC or an EventsMCMC object.

...

Currently not used.

level

A length-one numeric vector giving the confidence level.

Methods (by class)

  • hiatus(x = numeric, y = numeric): Returns a length-three numeric vector (terminal times and hiatus duration, if any).

  • hiatus(x = EventsMCMC, y = missing): Returns a TimeRange object.

  • hiatus(x = PhasesMCMC, y = missing): Returns a TimeRange object.

Author

A. Philippe, M.-A. Vibet, N. Frerebeau

Details

Finds if a gap exists between two dates and returns the longest interval that satisfies \(P(x < HiatusInf < HiatusSup < y | M) = level\)

The hiatus between two successive phases is the longest interval that satisfies \(P(Phase1Max < IntervalInf < IntervalSup < Phase2Min | M) = level\) (this assumes that the phases are in temporal order constraint).

See Also

Other time ranges: boundaries(), transition()

Examples

Run this code
## Coerce to MCMC
eve <- as_events(mcmc_events, calendar = CE(), iteration = 1)
eve <- eve[1:10000, ]

## Test for anteriority
older(eve)

## Test for hiatus
hia <- hiatus(eve)
as.data.frame(hia)

Run the code above in your browser using DataLab