data frame containing the output of the MCMC algorithm.
position
Numeric vector containing the position of the column
corresponding to the MCMC chains of interest, or a list of column names.
level
Probability corresponding to the level of confidence used
for the credible interval.
round_to
Integer indicating the number of decimal places.
Value
Returns a list with the following components:
ci
A data frame with a row for each column in data and two
columns: inf, the lower credible interval in calendar years (BC/AD);
and sup, the upper credible interval in calendar years (BC/AD).
level
Probability corresponding to the level of confidence used
for the credible interval.
call
The function call.
Details
A \((100 * level)\)\
that keeps \(N * (1 -level)\) elements of the sample outside the interval.
The \((100*level)\)\