powered by
Get or set the names of an object.
# S4 method for MCMC names(x)# S4 method for MCMC names(x) <- value# S4 method for PhasesMCMC names(x)# S4 method for PhasesMCMC names(x) <- value
# S4 method for MCMC names(x) <- value
# S4 method for PhasesMCMC names(x)
# S4 method for PhasesMCMC names(x) <- value
An object of the same sort as x with the new names assigned.
x
An object from which to get or set names.
A possible value for the names of x.
N. Frerebeau
Other mutators: bind, data.frame, sort(), sort.list(), subset()
bind
data.frame
sort()
sort.list()
subset()