Checks whether or not a file is identical to the one used to create
an archaeophases_mcmc object.
# S3 method for archaeophases_mcmc
original_file(x, file = NULL, ...)An archaeophases_mcmc object.
Either a path to a CSV file, a connection,
or the value clipboard() to read from the system clipboard.
The CSV file can be compressed or plain.
Other parameters.
A boolean, TRUE if the files match, FALSE
otherwise.
If called with a single argument, checks the file indicated by
the file_path attribute.